@@ -61,7 +61,7 @@
 // event tables and other macros for wxWidgets
 // ----------------------------------------------------------------------------
 
-DEFINE_EVENT_TYPE(EVT_QUEUE_PROGRESS)
+wxDEFINE_EVENT(EVT_QUEUE_PROGRESS, wxCommandEvent);
 
 BEGIN_EVENT_TABLE(MyExecPanel, wxPanel)
     EVT_TIMER(wxID_ANY, MyExecPanel::OnTimer)
@@ -354,7 +354,7 @@ void MyExecPanel::AddToOutput(wxInputStream & s)
         if (c == '\b') {
             lastCR=false;
             // backspace
-            if (currLine.size() > 0) {
+            if (!currLine.empty()) {
                 if (currLine.Last() != wxChar('\n') )
                     currLine.Trim();
             }
@@ -364,7 +364,7 @@ void MyExecPanel::AddToOutput(wxInputStream & s)
             // back to start of line
              if (currLine.Last() != wxChar('\n') ) {
                 currLine = currLine.BeforeLast('\n');
-                if(currLine.size() > 0) {
+                if(!currLine.empty()) {
                     currLine.Append('\n');
                 }
              }
@@ -378,7 +378,7 @@ void MyExecPanel::AddToOutput(wxInputStream & s)
             // back to start of line
                 if (currLine.Last() != wxChar('\n') ) {
                     currLine = currLine.BeforeLast('\n');
-                    if(currLine.size() > 0) {
+                    if(!currLine.empty()) {
                         currLine.Append('\n');
                     }
                 }
@@ -502,6 +502,16 @@ void MyExecPanel::CopyLogToClipboard()
     m_textctrl->Copy();
 };
 
+wxArrayString MyExecPanel::GetLogAsArrayString()
+{
+    wxArrayString output;
+    for (size_t i = 0; i < m_textctrl->GetNumberOfLines(); ++i)
+    {
+        output.push_back(m_textctrl->GetLineText(i));
+    }
+    return output;
+};
+
 void MyExecPanel::AddString(const wxString& s)
 {
     if (!s.IsEmpty())
