@@ -153,11 +153,12 @@ LensCalFrame::LensCalFrame(wxWindow* parent)
 
     // set the minimize icon
 #ifdef __WXMSW__
-    wxIcon myIcon(GetXRCPath() + wxT("data/hugin.ico"),wxBITMAP_TYPE_ICO);
+    wxIconBundle myIcons(GetXRCPath() + wxT("data/hugin.ico"), wxBITMAP_TYPE_ICO);
+    SetIcons(myIcons);
 #else
     wxIcon myIcon(GetXRCPath() + wxT("data/hugin.png"),wxBITMAP_TYPE_PNG);
-#endif
     SetIcon(myIcon);
+#endif
     SetTitle(_("Hugin Lens calibration GUI"));
 
     // create a new drop handler. wxwindows deletes the automatically
