@@ -120,12 +120,13 @@ AboutDialog::AboutDialog(wxWindow *parent)
 
     // load the appropriate icon (.ico for Windows, .png for other systems)
 #ifdef __WXMSW__
-    wxIcon myIcon(huginApp::Get()->GetXRCPath() + wxT("data/hugin.ico"),wxBITMAP_TYPE_ICO);
+    wxIconBundle myIcons(huginApp::Get()->GetXRCPath() + wxT("data/hugin.ico"),wxBITMAP_TYPE_ICO);
+    SetIcons(myIcons);
 #else
     wxIcon myIcon(huginApp::Get()->GetXRCPath() + wxT("data/hugin.png"),wxBITMAP_TYPE_PNG);
-#endif
     // set the icon in the title bar
     SetIcon(myIcon);
+#endif
 
     // set the position and the size (x,y,width,height). -1 = keep existing
     SetSize(1,1,560,560);
