@@ -42,6 +42,7 @@ BEGIN_EVENT_TABLE(ImageVariableDialog,wxDialog)
     EVT_BUTTON(XRCID("image_show_distortion_graph"), ImageVariableDialog::OnShowDistortionGraph)
     EVT_BUTTON(XRCID("image_show_vignetting_graph"), ImageVariableDialog::OnShowVignettingGraph)
     EVT_BUTTON(XRCID("image_show_response_graph"), ImageVariableDialog::OnShowResponseGraph)
+    EVT_CHOICE(XRCID("image_variable_responseType"), ImageVariableDialog::OnResponseSelected)
 END_EVENT_TABLE()
 
 ImageVariableDialog::ImageVariableDialog(wxWindow *parent, HuginBase::Panorama* pano, HuginBase::UIntSet imgs)
@@ -51,11 +52,13 @@ ImageVariableDialog::ImageVariableDialog(wxWindow *parent, HuginBase::Panorama*
     wxXmlResource::Get()->LoadDialog(this, parent, wxT("image_variables_dialog"));
 
 #ifdef __WXMSW__
-    wxIcon myIcon(huginApp::Get()->GetXRCPath() + wxT("data/hugin.ico"),wxBITMAP_TYPE_ICO);
+    wxIconBundle myIcons(huginApp::Get()->GetXRCPath() + wxT("data/hugin.ico"),wxBITMAP_TYPE_ICO);
+    SetIcons(myIcons);
 #else
     wxIcon myIcon(huginApp::Get()->GetXRCPath() + wxT("data/hugin.png"),wxBITMAP_TYPE_PNG);
-#endif
     SetIcon(myIcon);
+#endif
+
     wxConfigBase * cfg = wxConfigBase::Get();
     //position
     int x = cfg->Read(wxT("/ImageVariablesDialog/positionX"),-1l);
@@ -149,6 +152,8 @@ void ImageVariableDialog::InitValues()
             GetImageVariableControl(this, *varname)->SetValue(hugin_utils::doubleTowxString(val,ndigits));
         };
     };
+    wxCommandEvent dummy;
+    OnResponseSelected(dummy);
 };
 
 void ImageVariableDialog::SetGuiLevel(GuiLevel newLevel)
@@ -285,6 +290,26 @@ void ImageVariableDialog::OnHelp(wxCommandEvent & e)
     };
 };
 
+void ImageVariableDialog::OnResponseSelected(wxCommandEvent& e)
+{
+    const bool showResponseParam = XRCCTRL(*this, "image_variable_responseType", wxChoice)->GetSelection() == 0;
+    wxTextCtrl* control = XRCCTRL(*this, "image_variable_Ra", wxTextCtrl);
+    control->Enable(showResponseParam);
+    control->Show(showResponseParam);
+    control = XRCCTRL(*this, "image_variable_Rb", wxTextCtrl);
+    control->Enable(showResponseParam);
+    control->Show(showResponseParam);
+    control = XRCCTRL(*this, "image_variable_Rc", wxTextCtrl);
+    control->Enable(showResponseParam);
+    control->Show(showResponseParam);
+    control = XRCCTRL(*this, "image_variable_Rd", wxTextCtrl);
+    control->Enable(showResponseParam);
+    control->Show(showResponseParam);
+    control = XRCCTRL(*this, "image_variable_Re", wxTextCtrl);
+    control->Enable(showResponseParam);
+    control->Show(showResponseParam);
+};
+
 const char *ImageVariableDialog::m_varNames[] = { "y", "p", "r", "TrX", "TrY", "TrZ", "Tpy", "Tpp", 
                                   "v", "a", "b", "c", "d", "e", "g", "t",
                                   "Eev", "Er", "Eb", 
