@@ -647,11 +647,12 @@ MainFrame::MainFrame(wxWindow* parent, HuginBase::Panorama & pano)
 
     // set the minimize icon
 #ifdef __WXMSW__
-    wxIcon myIcon(GetXRCPath() + wxT("data/hugin.ico"),wxBITMAP_TYPE_ICO);
+    wxIconBundle myIcons(GetXRCPath() + wxT("data/hugin.ico"), wxBITMAP_TYPE_ICO);
+    SetIcons(myIcons);
 #else
     wxIcon myIcon(GetXRCPath() + wxT("data/hugin.png"),wxBITMAP_TYPE_PNG);
-#endif
     SetIcon(myIcon);
+#endif
 
     // create a new drop handler. wxwindows deletes the automaticall
     SetDropTarget(new PanoDropTarget(pano));
@@ -790,7 +791,11 @@ void MainFrame::panoramaChanged(HuginBase::Panorama &pano)
     // set flag to indicate list should show correlation instead of error
     if (m_showCorrelation == 2)
     {
-        m_showCorrelation = 0;
+        const std::string lastCommand = PanoCommand::GlobalCmdHist::getInstance().getLastCommandName();
+        if (!(lastCommand == "remove control point" || lastCommand == "remove control points"))
+        {
+            m_showCorrelation = 0;
+        };
     };
     if (m_showCorrelation == 1)
     {
@@ -2434,8 +2439,7 @@ void MainFrame::RunAssistant(wxWindow* mainWin, const wxString& userdefinedAssis
 
     //read back panofile
     PanoCommand::GlobalCmdHist::getInstance().addCommand(new PanoCommand::wxLoadPTProjectCmd(pano,
-        (const char *)scriptFileName.GetFullPath().mb_str(HUGIN_CONV_FILENAME), 
-        (const char *)scriptFileName.GetPath(wxPATH_NATIVE | wxPATH_GET_SEPARATOR).mb_str(HUGIN_CONV_FILENAME), 
+        (const char *)scriptFileName.GetFullPath().mb_str(HUGIN_CONV_FILENAME), "",
         ret==0, false));
 
     //delete temporary files
