@@ -921,7 +921,7 @@ void MaskImageCtrl::OnRightMouseUp(wxMouseEvent& mouse)
                         for(HuginBase::UIntSet::const_reverse_iterator it=points.rbegin();it!=points.rend();++it)
                             m_editingMask.removePoint(*it);
                         // now update set of selected points
-                        if(m_selectedPoints.size()>0)
+                        if(!m_selectedPoints.empty())
                         {
                             std::vector<unsigned int> mappedSelectedPoints(m_imageMask[m_activeMask].getMaskPolygon().size());
                             for(unsigned int i=0;i<mappedSelectedPoints.size();i++)
@@ -945,7 +945,7 @@ void MaskImageCtrl::OnRightMouseUp(wxMouseEvent& mouse)
                     else
                         wxBell();
                 };
-                if(m_selectedPoints.size()==0)
+                if(m_selectedPoints.empty())
                     m_maskEditState=NO_SELECTION;
                 else
                     m_maskEditState=POINTS_SELECTED;
@@ -975,7 +975,7 @@ void MaskImageCtrl::OnRightMouseUp(wxMouseEvent& mouse)
 
 void MaskImageCtrl::OnKeyUp(wxKeyEvent &e)
 {
-    int key=e.GetKeyCode();
+    const int key=e.GetKeyCode();
     bool processed=false;
     if((key==WXK_DELETE) || (key==WXK_NUMPAD_DELETE))
     {
@@ -983,7 +983,7 @@ void MaskImageCtrl::OnKeyUp(wxKeyEvent &e)
         {
             if (m_maskEditState == POINTS_SELECTED)
             {
-                if ((m_selectedPoints.size()>0) && (m_editingMask.getMaskPolygon().size() - m_selectedPoints.size() > 2))
+                if ((!m_selectedPoints.empty()) && (m_editingMask.getMaskPolygon().size() - m_selectedPoints.size() > 2))
                 {
                     for (HuginBase::UIntSet::const_reverse_iterator it = m_selectedPoints.rbegin(); it != m_selectedPoints.rend(); ++it)
                         m_editingMask.removePoint(*it);
@@ -1013,6 +1013,41 @@ void MaskImageCtrl::OnKeyUp(wxKeyEvent &e)
                 };
             };
         };
+    }
+    else
+    {
+        // handle key 0|1|2 only when editor state allows it
+        if (m_maskEditState == NO_MASK || m_maskEditState == NO_SELECTION ||
+            m_maskEditState == POINTS_SELECTED || m_maskEditState == CROP_SHOWING)
+        {
+            if (key == '1')
+            {
+                wxCommandEvent zoomEvent(wxEVT_CHOICE, XRCID("mask_editor_choice_zoom"));
+                zoomEvent.SetInt(0);
+                zoomEvent.SetString("update_selection");
+                GetParent()->GetEventHandler()->AddPendingEvent(zoomEvent);
+            }
+            else
+            {
+                if (key == '2')
+                {
+                    wxCommandEvent zoomEvent(wxEVT_CHOICE, XRCID("mask_editor_choice_zoom"));
+                    zoomEvent.SetInt(2);
+                    zoomEvent.SetString("update_selection");
+                    GetParent()->GetEventHandler()->AddPendingEvent(zoomEvent);
+                }
+                else
+                {
+                    if (key == '0')
+                    {
+                        wxCommandEvent zoomEvent(wxEVT_CHOICE, XRCID("mask_editor_choice_zoom"));
+                        zoomEvent.SetInt(1);
+                        zoomEvent.SetString("update_selection");
+                        GetParent()->GetEventHandler()->AddPendingEvent(zoomEvent);
+                    };
+                };
+            };
+        };
     };
     if(!processed)
         e.Skip();
@@ -1177,7 +1212,7 @@ void MaskImageCtrl::OnDraw(wxDC & dc)
                 dc.DrawRectangle(0,m_bitmap.GetHeight()+2*offset,clientSize.GetWidth(),clientSize.GetHeight()-m_bitmap.GetHeight()+2*offset);
             };
         };
-        if (m_maskMode && m_showActiveMasks && (m_cropMode != HuginBase::SrcPanoImage::NO_CROP || m_masksToDraw.size()>0))
+        if (m_maskMode && m_showActiveMasks && (m_cropMode != HuginBase::SrcPanoImage::NO_CROP || !m_masksToDraw.empty()))
         {
             //whole image, we need it several times
             wxRegion wholeImage(transform(applyRot(hugin_utils::FDiff2D(0,0))),
@@ -1212,7 +1247,7 @@ void MaskImageCtrl::OnDraw(wxDC & dc)
                         break;
                 };
             };
-            if(m_masksToDraw.size()>0)
+            if(!m_masksToDraw.empty())
             {
                 for(unsigned int i=0;i<m_masksToDraw.size();i++)
                 {
@@ -1250,7 +1285,7 @@ void MaskImageCtrl::OnDraw(wxDC & dc)
             dc.DestroyClippingRegion();
         };
         DrawCrop(dc);
-        if(m_maskMode && m_imageMask.size()>0)
+        if(m_maskMode && !m_imageMask.empty())
         {
             //now draw all polygons
             HuginBase::MaskPolygonVector maskList=m_imageMask;
@@ -1332,7 +1367,16 @@ void MaskImageCtrl::rescaleImage()
     {
         m_imageSize.SetWidth(scale(m_imageSize.GetWidth()));
         m_imageSize.SetHeight(scale(m_imageSize.GetHeight()));
-        img=img.Scale(scale(m_realSize.GetWidth()), scale(m_realSize.GetHeight()));
+        wxImageResizeQuality resizeQuality = wxIMAGE_QUALITY_NORMAL;
+        if (std::max(img.GetWidth(), img.GetHeight()) > (ULONG_MAX >> 16))
+        {
+            // wxIMAGE_QUALITY_NORMAL resizes the image with ResampleNearest
+            // this algorithm works only if image dimensions are smaller then 
+            // ULONG_MAX >> 16 (actual size of unsigned long differ from system
+            // to system)
+            resizeQuality = wxIMAGE_QUALITY_BOX_AVERAGE;
+        };
+        img=img.Scale(scale(m_realSize.GetWidth()), scale(m_realSize.GetHeight()), resizeQuality);
     }
     else
     {
