@@ -528,6 +528,7 @@ PanosphereOverviewVisualizationState::PanosphereOverviewVisualizationState(Hugin
     angy = 0;
     fov = 40;
     R = 500;
+    m_insideView = true;
     sphere_radius = 100;
 
     opts = (*(m_view_state->GetOptions()));
@@ -574,6 +575,21 @@ void PanosphereOverviewVisualizationState::setAngY(double angy_in)
     dirty_draw = true;
 }
 
+void PanosphereOverviewVisualizationState::setFOV(double newFOV)
+{
+    // limit new fov to 5 - 140 deg
+    fov = std::max(std::min(newFOV, 140.0), 5.0);
+}
+
+void PanosphereOverviewVisualizationState::setInsideView(bool insideView)
+{
+    if (m_insideView != insideView)
+    {
+        // inside/outside view changed, reset fov
+        setFOV(40);
+        m_insideView = insideView;
+    };
+}
 
 PlaneOverviewVisualizationState::PlaneOverviewVisualizationState(HuginBase::Panorama* pano, ViewState* view_state, GLViewer * viewer, void(*RefreshFunction)(void*), void *arg)
         : OverviewVisualizationState(pano, view_state, viewer, RefreshFunction, arg, (PlaneOverviewMeshManager*) NULL) 
