@@ -13,12 +13,6 @@
 #define CELESTEIMPEX __declspec(dllimport)
 #endif
 
-#if defined makefilelib_EXPORTS
-#define MAKEIMPEX __declspec(dllexport)
-#else
-#define MAKEIMPEX __declspec(dllimport)
-#endif
-
 #if defined icpfindlib_EXPORTS
 #define ICPIMPEX __declspec(dllexport)
 #else
@@ -44,9 +38,7 @@
 #else
 #define IMPEX
 #define WXIMPEX
-#define MAKEIMPEX
 #define LFIMPEX
 #define ICPIMPEX
 #define CELESTEIMPEX
-#define LINESIMPEX
 #endif
